==> estateplat-common-1.2.4-20200502.090138-337-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslMsrxwsx.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:xusong@gtmap.cn">xusong</a>
 * @version 1.0, 2019-11-26
 * @description: 一窗受理买受人询问事项
 */
@Entity
@Table( name ="YCSL_MSRXWSX" )
public class YcslMsrxwsx implements Serializable {

    private static final long serialVersionUID = -4828169251062970232L;
    /**
     * 主键
     */
    @Column(name = "MSRXWSXID")
    @Id
    private String msrxwsxid;
    /**
     * 项目ID
     */
    @Column(name = "PROID")
    private String proid;
    /**
     * 现购住房为家庭第几套房
     */
    @Column(name = "XGZFWJTDJTF")
    private Integer xgzfwjtdjtf;
    /**
     * 现购住房为家庭第几套房其他
     */
    @Column(name = "XGZFWJTDJTFQT")
    private String xgzfwjtdjtfqt;
    /**
     * 是否共有
     */
    @Column(name = "SFGY")
    private Integer sfgy;
    /**
     * 共有类型
     */
    @Column(name = "GYLX")
    private String gylx;
    /**
     * 是否分别持证
     */
    @Column(name = "SFFBCZ")
    private Integer sffbcz;
    /**
     * 是否委托领证
     */
    @Column(name = "SFWTLZ")
    private Integer sfwtlz;
    /**
     * 权利比例
     */
    @Column(name = "GYQK")
    private String gyqk;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getXgzfwjtdjtfqt() {
        return xgzfwjtdjtfqt;
    }

    public void setXgzfwjtdjtfqt(String xgzfwjtdjtfqt) {
        this.xgzfwjtdjtfqt = xgzfwjtdjtfqt;
    }

    public String getGylx() {
        return gylx;
    }

    public void setGylx(String gylx) {
        this.gylx = gylx;
    }
    public Integer getXgzfwjtdjtf() {
        return xgzfwjtdjtf;
    }

    public void setXgzfwjtdjtf(Integer xgzfwjtdjtf) {
        this.xgzfwjtdjtf = xgzfwjtdjtf;
    }

    public Integer getSfgy() {
        return sfgy;
    }

    public void setSfgy(Integer sfgy) {
        this.sfgy = sfgy;
    }

    public Integer getSffbcz() {
        return sffbcz;
    }

    public void setSffbcz(Integer sffbcz) {
        this.sffbcz = sffbcz;
    }

    public Integer getSfwtlz() {
        return sfwtlz;
    }

    public void setSfwtlz(Integer sfwtlz) {
        this.sfwtlz = sfwtlz;
    }

    public String getMsrxwsxid() {
        return msrxwsxid;
    }

    public void setMsrxwsxid(String msrxwsxid) {
        this.msrxwsxid = msrxwsxid;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }
}

==> estateplat-common-1.2.4-20230406.084733-1153-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslMsrxwsx.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:xusong@gtmap.cn">xusong</a>
 * @version 1.0, 2019-11-26
 * @description: 一窗受理买受人询问事项
 */
@Entity
@Table( name ="YCSL_MSRXWSX" )
public class YcslMsrxwsx implements Serializable {

    private static final long serialVersionUID = -4828169251062970232L;
    /**
     * 主键
     */
    @Column(name = "MSRXWSXID")
    @Id
    private String msrxwsxid;
    /**
     * 项目ID
     */
    @Column(name = "PROID")
    private String proid;
    /**
     * 现购住房为家庭第几套房
     */
    @Column(name = "XGZFWJTDJTF")
    private Integer xgzfwjtdjtf;
    /**
     * 现购住房为家庭第几套房其他
     */
    @Column(name = "XGZFWJTDJTFQT")
    private String xgzfwjtdjtfqt;
    /**
     * 是否共有
     */
    @Column(name = "SFGY")
    private Integer sfgy;
    /**
     * 共有类型
     */
    @Column(name = "GYLX")
    private String gylx;
    /**
     * 是否分别持证
     */
    @Column(name = "SFFBCZ")
    private Integer sffbcz;
    /**
     * 是否委托领证
     */
    @Column(name = "SFWTLZ")
    private Integer sfwtlz;
    /**
     * 权利比例
     */
    @Column(name = "GYQK")
    private String gyqk;

    /**
     * 委托人姓名
     */
    @Column(name = "WTRXM")
    private String wtrxm;

    /**
     * 委托人证件号
     */
    @Column(name = "WTRZJH")
    private String wtrzjh;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getXgzfwjtdjtfqt() {
        return xgzfwjtdjtfqt;
    }

    public void setXgzfwjtdjtfqt(String xgzfwjtdjtfqt) {
        this.xgzfwjtdjtfqt = xgzfwjtdjtfqt;
    }

    public String getGylx() {
        return gylx;
    }

    public void setGylx(String gylx) {
        this.gylx = gylx;
    }
    public Integer getXgzfwjtdjtf() {
        return xgzfwjtdjtf;
    }

    public void setXgzfwjtdjtf(Integer xgzfwjtdjtf) {
        this.xgzfwjtdjtf = xgzfwjtdjtf;
    }

    public Integer getSfgy() {
        return sfgy;
    }

    public void setSfgy(Integer sfgy) {
        this.sfgy = sfgy;
    }

    public Integer getSffbcz() {
        return sffbcz;
    }

    public void setSffbcz(Integer sffbcz) {
        this.sffbcz = sffbcz;
    }

    public Integer getSfwtlz() {
        return sfwtlz;
    }

    public void setSfwtlz(Integer sfwtlz) {
        this.sfwtlz = sfwtlz;
    }

    public String getMsrxwsxid() {
        return msrxwsxid;
    }

    public void setMsrxwsxid(String msrxwsxid) {
        this.msrxwsxid = msrxwsxid;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getWtrxm() {
        return wtrxm;
    }

    public void setWtrxm(String wtrxm) {
        this.wtrxm = wtrxm;
    }

    public String getWtrzjh() {
        return wtrzjh;
    }

    public void setWtrzjh(String wtrzjh) {
        this.wtrzjh = wtrzjh;
    }
}
